@@ -1,6 +1,6 @@
 '''cr_lint.py: click lint checks'''
 #
-# Copyright (C) 2013-2014 Canonical Ltd.
+# Copyright (C) 2013-2015 Canonical Ltd.
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -45,12 +45,13 @@ class ClickReviewLint(ClickReview):
         #  arm64  - compiled, single arch (not available yet)
         #  ppc64el - compiled, single arch (not available yet)
         #  powerpc - compiled, single arch (not available yet)
+        self.valid_compiled_architectures = ['armhf',
+                                             'i386',
+                                             'amd64',
+                                             ]
         self.valid_control_architectures = ['all',
                                             'multi',
-                                            'armhf',
-                                            'i386',
-                                            'amd64',
-                                            ]
+                                            ] + self.valid_compiled_architectures
         self.vcs_dirs = ['.bzr*', '.git*', '.svn*', '.hg', 'CVS*', 'RCS*']
 
         if 'maintainer' in self.manifest:
@@ -59,8 +60,10 @@ class ClickReviewLint(ClickReview):
             self.is_core_app = (self.click_pkgname.startswith('com.ubuntu.')
                                 and not self.click_pkgname.startswith(
                                     'com.ubuntu.developer.')
-                                and self.email ==
-                                'ubuntu-touch-coreapps@lists.launchpad.net')
+                                and (self.email ==
+                                'ubuntu-touch-coreapps@lists.launchpad.net' or
+                                     self.email ==
+                                     'ubuntu-devel-discuss@lists.ubuntu.com'))
             # "core scope" is not necessarily a word we use right now, but
             # we want to special case scopes which are written through our
             # vetted development process.
@@ -86,6 +89,7 @@ class ClickReviewLint(ClickReview):
                             'account-qml-plugin',
                             'account-service',
                             'apparmor',
+                            'apparmor-profile',
                             'bin-path',
                             'content-hub',
                             'desktop',
@@ -98,6 +102,7 @@ class ClickReviewLint(ClickReview):
 
         self.redflagged_hooks = ['framework',
                                  'pay-ui',
+                                 'apparmor-profile',
                                  ]
         if overrides is None:
             overrides = {}
@@ -200,7 +205,19 @@ class ClickReviewLint(ClickReview):
         n = 'control_architecture_match'
         s = 'OK'
         if 'architecture' in self.manifest:
-            if control['Architecture'] != self.manifest['architecture']:
+            if control['Architecture'] == "multi":
+                if not isinstance(self.manifest['architecture'],
+                                  (list, tuple)):
+                    t = 'error'
+                    s = 'If arch=multi, manifest architecture needs to ' + \
+                        'list all the individual architectures.'
+                elif list(filter(lambda a:
+                                 a not in self.valid_compiled_architectures,
+                                 self.manifest['architecture'])):
+                    t = 'error'
+                    s = 'If arch=multi, manifest architecture needs to ' + \
+                        'comprise of only compiled architectures.'
+            elif control['Architecture'] != self.manifest['architecture']:
                 t = 'error'
                 s = "Architecture=%s " % control['Architecture'] + \
                     "does not match manifest architecture=%s" % \
@@ -359,10 +376,16 @@ exit 1
                 if f not in self.manifest['hooks'][app]:
                     # TODO: when have apparmor policy for account-provider and
                     #       account-qml-plugin, remove this conditional
-                    if f != 'apparmor' or \
-                       len(self.manifest['hooks'][app]) != 2 or \
-                       'account-provider' not in self.manifest['hooks'][app] or \
-                       'account-qml-plugin' not in self.manifest['hooks'][app]:
+                    if f == 'apparmor' and \
+                       'apparmor-profile' in self.manifest['hooks'][app]:
+                        # Don't require apparmor if have apparmor-profile
+                        pass
+                    elif f != 'apparmor' or \
+                            len(self.manifest['hooks'][app]) != 2 or \
+                            'account-provider' not in \
+                            self.manifest['hooks'][app] or \
+                            'account-qml-plugin' not in \
+                            self.manifest['hooks'][app]:
                         t = 'error'
                         s = "'%s' hook not found for '%s'" % (f, app)
                 self._add_result(t, n, s)
@@ -512,7 +535,7 @@ exit 1
             return
 
         if len(self.pkg_bin_files) == 0:
-            t = 'error'
+            t = 'warn'
             s = "Could not find compiled binaries for architecture '%s'" % \
                 self.click_arch
         self._add_result(t, n, s)
@@ -650,12 +673,12 @@ exit 1
         s = 'OK'
         if len(tmp) != 3:
             t = 'warn'
-            s = "'%s' not of form $pkgname_$version_$arch.click" % \
+            s = "'%s' not of form $pkgname_$version_$arch.[click|snap]" % \
                 os.path.basename(self.click_package)
         self._add_result(t, n, s)
 
         #  handle $pkgname.click or $pkgname.snap
-        if tmp[0].endswith('.snap'):
+        if self.click_package.endswith('.snap'):
             pkgname = tmp[0].partition('.snap')[0]
         else:
             pkgname = tmp[0].partition('.click')[0]
@@ -692,7 +715,7 @@ exit 1
         l = None
         if len(tmp) >= 2:
             #  handle $pkgname_$version.click or $pkgname_$version.snap
-            if tmp[0].endswith('.snap'):
+            if self.click_package.endswith('.snap'):
                 version = tmp[1].partition('.snap')[0]
             else:
                 version = tmp[1].partition('.click')[0]
@@ -711,7 +734,7 @@ exit 1
         n = 'package_filename_arch_valid'
         s = 'OK'
         if len(tmp) >= 3:
-            if tmp[0].endswith('.snap'):
+            if self.click_package.endswith('.snap'):
                 arch = tmp[2].partition('.snap')[0]
             else:
                 arch = tmp[2].partition('.click')[0]
@@ -735,7 +758,7 @@ exit 1
         n = 'package_filename_arch_match'
         s = 'OK'
         if len(tmp) >= 3:
-            if tmp[0].endswith('.snap'):
+            if self.click_package.endswith('.snap'):
                 arch = tmp[2].partition('.snap')[0]
             else:
                 arch = tmp[2].partition('.click')[0]
