@@ -1,6 +1,6 @@
 '''test_cr_lint.py: tests for the cr_lint module'''
 #
-# Copyright (C) 2013-2014 Canonical Ltd.
+# Copyright (C) 2013-2015 Canonical Ltd.
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -172,7 +172,7 @@ class TestClickReviewLint(cr_tests.TestClickReview):
         c.pkg_bin_files = []
         c.check_architecture_specified_needed()
         r = c.click_report
-        expected_counts = {'info': None, 'warn': 0, 'error': 1}
+        expected_counts = {'info': None, 'warn': 1, 'error': 0}
         self.check_results(r, expected_counts)
 
     def test_check_architecture_specified_needed2(self):
@@ -367,6 +367,20 @@ class TestClickReviewLint(cr_tests.TestClickReview):
         expected_counts = {'info': 1, 'warn': 0, 'error': 0}
         self.check_results(r, expected_counts)
 
+    def test_check_manifest_valid_arch_multi2(self):
+        '''Test check_manifest_architecture() (valid multi2)'''
+        arch = "multi"
+        self.set_test_manifest("architecture", ["armhf", "i386"])
+        self.set_test_control("Architecture", arch)
+        test_name = "%s_%s_%s.click" % (self.test_control['Package'],
+                                        self.test_control['Version'],
+                                        arch)
+        c = ClickReviewLint(test_name)
+        c.check_manifest_architecture()
+        r = c.click_report
+        expected_counts = {'info': 1, 'warn': 0, 'error': 0}
+        self.check_results(r, expected_counts)
+
     def test_check_manifest_invalid_arch_multi_nonexistent(self):
         '''Test check_manifest_architecture() (invalid multi)'''
         arch = "multi"
@@ -766,6 +780,17 @@ class TestClickReviewLint(cr_tests.TestClickReview):
         expected_counts = {'info': None, 'warn': 0, 'error': 1}
         self.check_results(r, expected_counts)
 
+    def test_check_hooks_missing_apparmor_with_apparmor_profile(self):
+        '''Test check_hooks() - missing apparmor with apparmor-profile'''
+        self.set_test_manifest("framework", "ubuntu-sdk-13.10")
+        c = ClickReviewLint(self.test_name)
+        del c.manifest['hooks'][self.default_appname]['apparmor']
+        c.manifest['hooks'][self.default_appname]['apparmor-profile'] = 'foo'
+        c.check_hooks()
+        r = c.click_report
+        expected_counts = {'info': None, 'warn': 0, 'error': 0}
+        self.check_results(r, expected_counts)
+
     def test_check_hooks_has_desktop_and_scope(self):
         '''Test check_hooks() - desktop with scope'''
         self.set_test_manifest("framework", "ubuntu-sdk-13.10")
@@ -795,8 +820,8 @@ class TestClickReviewLint(cr_tests.TestClickReview):
         expected_counts = {'info': None, 'warn': 0, 'error': 0}
         self.check_results(r, expected_counts)
 
-    def test_check_hooks_redflagged(self):
-        '''Test check_hooks_redflagged()'''
+    def test_check_hooks_redflagged_payui(self):
+        '''Test check_hooks_redflagged() - pay-ui'''
         self.set_test_manifest("framework", "ubuntu-sdk-13.10")
         c = ClickReviewLint(self.test_name)
         c.manifest['hooks'][self.default_appname]["pay-ui"] = "foo"
@@ -805,3 +830,14 @@ class TestClickReviewLint(cr_tests.TestClickReview):
         expected_counts = {'info': None, 'warn': 0, 'error': 1}
         self.check_results(r, expected_counts)
         self.check_manual_review(r, 'lint_hooks_redflag_test-app')
+
+    def test_check_hooks_redflagged_apparmor_profile(self):
+        '''Test check_hooks_redflagged() - apparmor-profile'''
+        self.set_test_manifest("framework", "ubuntu-sdk-13.10")
+        c = ClickReviewLint(self.test_name)
+        c.manifest['hooks'][self.default_appname]["apparmor-profile"] = "foo"
+        c.check_hooks_redflagged()
+        r = c.click_report
+        expected_counts = {'info': None, 'warn': 0, 'error': 1}
+        self.check_results(r, expected_counts)
+        self.check_manual_review(r, 'lint_hooks_redflag_test-app')
